@@ -92,6 +92,9 @@ struct _ClockData {
 	PanelAppletOrient orient;
 	int size;
 
+	int fixed_width;
+	int fixed_height;
+
 	guint listeners [N_GCONF_PREFS];
 };
 
@@ -110,6 +113,14 @@ static void display_about_dialog      (BonoboUIComponent *uic,
 				       ClockData         *cd,
 				       const gchar       *verbname);
 
+static void
+unfix_size (ClockData *cd)
+{
+	cd->fixed_width = -1;
+	cd->fixed_height = -1;
+	gtk_widget_queue_resize (cd->toggle);
+}
+
 static void
 set_tooltip (GtkWidget  *applet,
 	     GtkWidget  *widget,
@@ -345,6 +356,8 @@ refresh_clock (ClockData *cd)
 {
 	time_t current_time;
 	
+	unfix_size (cd);
+
 	time (&current_time);
 	update_clock (cd, current_time);
 }
@@ -353,6 +366,8 @@ static void
 refresh_clock_timeout(ClockData *cd)
 {
 	time_t current_time;
+
+	unfix_size (cd);
 	
 	update_timeformat (cd);
 
@@ -447,10 +462,11 @@ create_calendar (ClockData *cd,
 {
 	GtkWindow *window;
 	GtkWidget *calendar;
+	GtkCalendarDisplayOptions options;
 
 	window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
 
-	gtk_window_set_type_hint (window, GDK_WINDOW_TYPE_HINT_UTILITY);
+	gtk_window_set_type_hint (window, GDK_WINDOW_TYPE_HINT_DOCK);
 	gtk_window_set_decorated (window, FALSE);
 	gtk_window_set_resizable (window, FALSE);
 	gtk_window_stick (window);
@@ -464,6 +480,10 @@ create_calendar (ClockData *cd,
 			
 	calendar = gtk_calendar_new ();
 
+	options = gtk_calendar_get_display_options (GTK_CALENDAR (calendar));
+	options |= GTK_CALENDAR_SHOW_WEEK_NUMBERS;
+	gtk_calendar_set_display_options (GTK_CALENDAR (calendar), options);
+
 	gtk_container_add (GTK_CONTAINER (window), calendar);
 
 	gtk_widget_show (calendar);
@@ -478,10 +498,12 @@ present_calendar_popup (ClockData *cd,
 {
 	GtkRequisition  req;
 	GdkScreen      *screen;
+	GdkRectangle    monitor;
 	int             button_w, button_h;
-	int             screen_w, screen_h;
 	int             x, y;
 	int             w, h;
+	int             i, n;
+	gboolean        found_monitor = FALSE;
 		
 	/* Get root origin of the toggle button, and position above that. */
 	gdk_window_get_origin (button->window, &x, &y);
@@ -496,11 +518,25 @@ present_calendar_popup (ClockData *cd,
 
 	screen = gtk_window_get_screen (GTK_WINDOW (window));
 
-	/* FIXME use xinerama extents for xinerama containing
-	 * the applet.
-	 */
-	screen_w = gdk_screen_get_width (screen);
-	screen_h = gdk_screen_get_height (screen);
+	n = gdk_screen_get_n_monitors (screen);
+	for (i = 0; i < n; i++) {
+		gdk_screen_get_monitor_geometry (screen, i, &monitor);
+		if (x >= monitor.x && x <= monitor.x + monitor.width &&
+		    y >= monitor.y && y <= monitor.y + monitor.height) {
+			found_monitor = TRUE;
+			break;
+		}
+	}
+
+
+	if ( ! found_monitor) {
+		/* eek, we should be on one of those xinerama
+		   monitors */
+		monitor.x = 0;
+		monitor.y = 0;
+		monitor.width = gdk_screen_get_width (screen);
+		monitor.height = gdk_screen_get_height (screen);
+	}
 		
 	/* Based on panel orientation, position the popup.
 	 * Ignore window gravity since the window is undecorated.
@@ -510,23 +546,23 @@ present_calendar_popup (ClockData *cd,
 	switch (cd->orient) {
 	case PANEL_APPLET_ORIENT_RIGHT:
 		x += button_w;
-		if ((y + h) > screen_h)
-			y -= (y + h) - screen_h;
-			break;
+		if ((y + h) > monitor.y + monitor.height)
+			y -= (y + h) - (monitor.y + monitor.height);
+		break;
 	case PANEL_APPLET_ORIENT_LEFT:
 		x -= w;
-		if ((y + h) > screen_h)
-			y -= (y + h) - screen_h;
+		if ((y + h) > monitor.y + monitor.height)
+			y -= (y + h) - (monitor.y + monitor.height);
 		break;
 	case PANEL_APPLET_ORIENT_DOWN:
 		y += button_h;
-		if ((x + w) > screen_w)
-			x -= (x + w) - screen_w;
+		if ((x + w) > monitor.x + monitor.width)
+			x -= (x + w) - (monitor.x + monitor.width);
 		break;
 	case PANEL_APPLET_ORIENT_UP:
 		y -= h;
-		if ((x + w) > screen_w)
-			x -= (x + w) - screen_w;
+		if ((x + w) > monitor.x + monitor.width)
+			x -= (x + w) - (monitor.x + monitor.width);
 		break;
 	}
 		
@@ -581,22 +617,50 @@ do_not_eat_button_press (GtkWidget      *widget,
 	return FALSE;
 }
 
+/* Don't request smaller size then the last one we did, this avoids
+   jumping when proportional fonts are used.  We must take care to 
+   call "unfix_size" whenever options are changed or such where
+   we'd want to forget the fixed size */
+static void
+clock_size_request (GtkWidget *clock, GtkRequisition *req, gpointer data)
+{
+	ClockData *cd = data;
+
+	if (req->width > cd->fixed_width)
+		cd->fixed_width = req->width;
+	if (req->height > cd->fixed_height)
+		cd->fixed_height = req->height;
+	req->width = cd->fixed_width;
+	req->height = cd->fixed_height;
+}
 
 static void
 create_clock_widget (ClockData *cd)
 {
 	GtkWidget *clock;
 	GtkWidget *toggle;
+	GtkWidget *alignment;
 
 	clock = gtk_label_new ("hmm?");
+	g_signal_connect (clock, "size_request",
+			  G_CALLBACK (clock_size_request),
+			  cd);
+	g_signal_connect_swapped (clock, "style_set",
+				  G_CALLBACK (unfix_size),
+				  cd);
 	gtk_label_set_justify (GTK_LABEL (clock), GTK_JUSTIFY_CENTER);
 	gtk_label_set_line_wrap (GTK_LABEL (clock), TRUE);
 	gtk_widget_show (clock);
 
 	toggle = gtk_toggle_button_new ();
+	gtk_container_set_resize_mode (GTK_CONTAINER (toggle), GTK_RESIZE_IMMEDIATE);
 	gtk_button_set_relief (GTK_BUTTON (toggle), GTK_RELIEF_NONE);
         
-	gtk_container_add (GTK_CONTAINER (toggle), clock);
+	alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
+	gtk_container_add (GTK_CONTAINER (alignment), clock);
+	gtk_container_set_resize_mode (GTK_CONTAINER (alignment), GTK_RESIZE_IMMEDIATE);
+	gtk_widget_show (alignment);
+	gtk_container_add (GTK_CONTAINER (toggle), alignment);
 
 	g_signal_connect (toggle, "button_press_event",
 			  G_CALLBACK (do_not_eat_button_press), NULL);
@@ -815,7 +879,8 @@ config_date (BonoboUIComponent *uic,
 	screen = gtk_widget_get_screen (cd->applet);
 
 	/* FIXME add other time config tools. */
-	if (cd->config_tool && try_config_tool (screen, cd->config_tool))
+	if (cd->config_tool && cd->config_tool[0]
+	    && try_config_tool (screen, cd->config_tool))
 		return;
 
 	else if (try_config_tool (screen, "redhat-config-date"))
@@ -1060,6 +1125,8 @@ fill_clock_applet (PanelApplet *applet)
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 	
 	cd = g_new0 (ClockData, 1);
+	cd->fixed_width = -1;
+	cd->fixed_height = -1;
 
 	cd->applet = GTK_WIDGET (applet);
 
@@ -1131,6 +1198,21 @@ fill_clock_applet (PanelApplet *applet)
 					   NULL,
 					   clock_menu_verbs,
 					   cd);
+
+	if (panel_applet_get_locked_down (PANEL_APPLET (cd->applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (cd->applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/ClockPreferences",
+					      "hidden", "1",
+					      NULL);
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/ClockConfig",
+					      "hidden", "1",
+					      NULL);
+	}
 	
 	return TRUE;
 }
