@@ -82,6 +82,10 @@ panel_applet_toggle_locked (AppletInfo *info)
 	
 	locked = panel_widget_toggle_applet_locked (panel_widget, info->widget);
 
+	if (panel_toplevel_get_locked_down (panel_widget->toplevel) ||
+	    panel_profile_get_locked_down ())
+		return TRUE;
+
 	panel_applet_save_position (info, info->id, TRUE);
 	panel_applet_set_dnd_enabled (info, !locked);
 
@@ -177,9 +181,6 @@ applet_callback_callback (GtkWidget      *widget,
 		if (!strcmp (menu->name, "properties"))
 			launcher_properties (
 				menu->info->data, screen);
-
-		else if (!strcmp (menu->name, "help_on_app"))
-			launcher_show_help (menu->info->data, screen);
 		break;
 	case PANEL_OBJECT_DRAWER: 
 		if (strcmp (menu->name, "properties")==0) {
@@ -437,6 +438,7 @@ panel_applet_create_menu (AppletInfo  *info,
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GList     *l;
+	gboolean   added_anything = FALSE;
 
 	menu = g_object_ref (panel_create_menu ());
 	gtk_object_sink (GTK_OBJECT (menu));
@@ -447,32 +449,34 @@ panel_applet_create_menu (AppletInfo  *info,
 	g_signal_connect (menu, "deactivate",
 			  G_CALLBACK (applet_menu_deactivate), info);
 
-	if (info->user_menu) {
-		for (l = info->user_menu; l; l = l->next) {
-			AppletUserMenu *user_menu = (AppletUserMenu *)l->data;
+	for (l = info->user_menu; l; l = l->next) {
+		AppletUserMenu *user_menu = (AppletUserMenu *)l->data;
 
-			add_to_submenus (info, "", user_menu->name, user_menu, 
-					 menu, info->user_menu);
-		}
+		add_to_submenus (info, "", user_menu->name, user_menu, 
+				 menu, info->user_menu);
+
+		added_anything = TRUE;
 	}
 
-	if (!commie_mode) {
+	if ( ! panel_profile_get_locked_down () &&
+	     ! panel_toplevel_get_locked_down (panel_widget->toplevel)) {
 		GtkWidget *image;
 		gboolean   locked;
 		gboolean   lockable;
 		gboolean   movable;
 		gboolean   removable;
 
-
 		lockable = panel_applet_lockable (info);
 		movable = panel_applet_can_freely_move (info);
 		removable = panel_profile_list_is_writable (PANEL_GCONF_OBJECTS);
 
 		locked = panel_widget_get_applet_locked (panel_widget, info->widget);
 
-		menuitem = gtk_separator_menu_item_new ();
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-		gtk_widget_show (menuitem);
+		if (added_anything) {
+			menuitem = gtk_separator_menu_item_new ();
+			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+			gtk_widget_show (menuitem);
+		}
 
 		menuitem = gtk_image_menu_item_new ();
 		image = gtk_image_new_from_stock (GTK_STOCK_REMOVE,
@@ -510,6 +514,13 @@ panel_applet_create_menu (AppletInfo  *info,
 		info->move_item = menuitem;
 		g_object_add_weak_pointer (G_OBJECT (menuitem),
 					   (gpointer *) &info->move_item);
+
+		added_anything = TRUE;
+	}
+
+	if ( ! added_anything) {
+		g_object_unref (menu);
+		return NULL;
 	}
 
 	return menu;
@@ -548,10 +559,11 @@ applet_show_menu (AppletInfo     *info,
 
 	panel_widget = PANEL_WIDGET (info->widget->parent);
 
-	if (!info->menu)
+	if (info->menu == NULL)
 		info->menu = panel_applet_create_menu (info, panel_widget);
 
-	g_assert (info->menu);
+	if (info->menu == NULL)
+		return;
 
 	panel_toplevel_block_auto_hide (panel_widget->toplevel);
 
@@ -1130,9 +1142,7 @@ panel_applet_register (GtkWidget       *applet,
 
 	orientation_change (info, panel);
 	size_change (info, panel);
-#ifdef FIXME_FOR_NEW_CONFIG
 	back_change (info, panel);
-#endif
 
 	if (type != PANEL_OBJECT_BONOBO)
 		gtk_widget_grab_focus (applet);
@@ -1160,10 +1170,21 @@ panel_applet_get_position (AppletInfo *applet)
 gboolean
 panel_applet_can_freely_move (AppletInfo *applet)
 {
-	GConfClient *client = panel_gconf_get_client ();
-	const char *profile = panel_profile_get_name ();
-	PanelGConfKeyType key_type = applet->type == PANEL_OBJECT_BONOBO ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
+	GConfClient *client;
+	const char *profile;
+	PanelGConfKeyType key_type;
 	const char *key;
+	PanelWidget *panel_widget;
+
+	panel_widget = PANEL_WIDGET (applet->widget->parent);
+
+	if (panel_toplevel_get_locked_down (panel_widget->toplevel) ||
+	    panel_profile_get_locked_down ())
+		return FALSE;
+
+	client = panel_gconf_get_client ();
+	profile = panel_profile_get_name ();
+	key_type = applet->type == PANEL_OBJECT_BONOBO ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
        
 	key = panel_gconf_full_key (key_type, profile, applet->id, "position");
 	if ( ! gconf_client_key_is_writable (client, key, NULL))
@@ -1181,9 +1202,22 @@ panel_applet_can_freely_move (AppletInfo *applet)
 gboolean
 panel_applet_lockable (AppletInfo *applet)
 {
-	GConfClient *client = panel_gconf_get_client ();
-	const char *profile = panel_profile_get_name ();
-	PanelGConfKeyType key_type = applet->type == PANEL_OBJECT_BONOBO ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
-	const char *key = panel_gconf_full_key (key_type, profile, applet->id, "locked");
+	GConfClient *client;
+	const char *profile;
+	PanelGConfKeyType key_type;
+	const char *key;
+	PanelWidget *panel_widget;
+
+	panel_widget = PANEL_WIDGET (applet->widget->parent);
+
+	if (panel_toplevel_get_locked_down (panel_widget->toplevel) ||
+	    panel_profile_get_locked_down ())
+		return FALSE;
+
+	client = panel_gconf_get_client ();
+	profile = panel_profile_get_name ();
+	key_type = applet->type == PANEL_OBJECT_BONOBO ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
+	key = panel_gconf_full_key (key_type, profile, applet->id, "locked");
+
 	return gconf_client_key_is_writable (client, key, NULL);
 }
