@@ -253,6 +253,7 @@ show_about_dialog (GtkWidget *menuitem)
 	char             *authors [] = {
 		"Alex Larsson (alexl@redhat.com)",
 		"Anders Carlsson (andersca@gnu.org)",
+		"Arvind Samptur (arvind.samptur@wipro.com)",
 		"Darin Adler (darin@bentspoon.com)",
 		"Elliot Lee (sopwith@redhat.com)",
 		"Federico Mena (quartic@gimp.org)",
@@ -269,6 +270,7 @@ show_about_dialog (GtkWidget *menuitem)
 		"Seth Nickell (snickell@stanford.edu)",
 		"Stephen Browne (stephen.browne@sun.com)",
 		"Tom Tromey (tromey@cygnus.com)",
+		"Vincent Untz (vincent@vuntz.net)",
 		N_("And many, many others..."),
 		NULL
 	};
@@ -338,7 +340,7 @@ activate_app_def (GtkWidget  *menuitem,
 
 	item = gnome_desktop_item_new_from_uri (
 			item_loc,
-			GNOME_DESKTOP_ITEM_LOAD_NO_TRANSLATIONS,
+			0,
 			&error);
 
 	if (item) {
@@ -1031,10 +1033,17 @@ static void
 add_new_app_to_menu (GtkWidget    *widget,
 		     ShowItemMenu *sim)
 {
+	GtkWidget *dialog;
+	PanelWidget *panel;
+
 	g_return_if_fail (sim->mf != NULL);
 
-	panel_new_launcher (sim->mf->menudir,
-			    menuitem_to_screen (sim->menuitem));
+	panel = menu_get_panel (sim->menuitem);
+
+	dialog = panel_new_launcher (sim->mf->menudir,
+			    	     menuitem_to_screen (sim->menuitem));
+
+	panel_widget_register_open_dialog (panel, dialog);
 }
 
 static void
@@ -1163,46 +1172,6 @@ add_to_run_dialog (GtkWidget    *widget,
 	}
 }
 
-static void
-show_help_on (GtkWidget    *widget,
-	      ShowItemMenu *sim)
-{
-	GError           *error = NULL;
-	GnomeDesktopItem *item;
-	GdkScreen        *screen;
-
-	screen = menuitem_to_screen (sim->menuitem);
-
-	item = gnome_desktop_item_new_from_uri (sim->item_loc,
-						GNOME_DESKTOP_ITEM_LOAD_NO_TRANSLATIONS,
-						&error);
-	if (item != NULL) {
-		const char *docpath = gnome_desktop_item_get_string
-			(item, "X-GNOME-DocPath");
-		if ( ! panel_show_gnome_kde_help (screen, docpath, &error)) {
-			panel_error_dialog (screen,
-					    "cannot_show_gnome_kde_help",
-					    _("Cannot display help document"),
-					    "%s",
-					    error->message);
-
-			g_clear_error (&error);
-		}
-
-		gnome_desktop_item_unref (item);
-	} else {
-		g_assert (error != NULL);
-
-		panel_error_dialog (screen,
-				    "cannot_load_entry",
-				    _("Cannot load entry"),
-				    "%s",
-				    error->message);
-
-		g_clear_error (&error);
-	}
-}
-
 static void
 add_app_to_panel (GtkWidget    *item,
 		  ShowItemMenu *sim)
@@ -1276,8 +1245,22 @@ add_drawers_from_dir (const char  *dirname,
 
 			else if ((g_str_has_suffix (mfile->name, ".desktop") ||
 				  g_str_has_suffix (mfile->name, ".kdelnk")) &&
-				 vfs_text_uri_exists (uri))
-				panel_launcher_create_with_id (attached_toplevel_id, G_MAXINT/2, uri);
+				 vfs_text_uri_exists (uri)) {
+					
+					QuickDesktopItem *qitem;
+
+					qitem = quick_desktop_item_load_uri (uri,
+									     NULL,
+									     TRUE);
+
+					/* Don't add the desktop entry if TryExec fails */
+					if (qitem != NULL) {
+						panel_launcher_create_with_id (
+									   attached_toplevel_id, 
+									   G_MAXINT/2, uri);
+						quick_desktop_item_destroy (qitem);
+					}
+			}
 		}
 
 		g_free (uri);
@@ -1360,13 +1343,21 @@ restore_grabs(GtkWidget *w, gpointer data)
 
 	/*only grab if this HAD a grab before*/
 	if (xgrab_shell && (GTK_MENU_SHELL (xgrab_shell)->have_xgrab))
-		GTK_MENU_SHELL (xgrab_shell)->have_xgrab = 
-			(gdk_pointer_grab (xgrab_shell->window, TRUE,
-					   GDK_BUTTON_PRESS_MASK |
-					   GDK_BUTTON_RELEASE_MASK |
-					   GDK_ENTER_NOTIFY_MASK |
-					   GDK_LEAVE_NOTIFY_MASK,
-					   NULL, NULL, 0) == 0);
+          {
+	    if (gdk_pointer_grab (xgrab_shell->window, TRUE,
+				  GDK_BUTTON_PRESS_MASK |
+				  GDK_BUTTON_RELEASE_MASK |
+				  GDK_ENTER_NOTIFY_MASK |
+				  GDK_LEAVE_NOTIFY_MASK,
+				  NULL, NULL, 0) == 0)
+              {
+		if (gdk_keyboard_grab (xgrab_shell->window, TRUE,
+				       GDK_CURRENT_TIME) == 0)
+		  GTK_MENU_SHELL (xgrab_shell)->have_xgrab = TRUE;
+		else
+		  gdk_pointer_ungrab (GDK_CURRENT_TIME);
+	      }
+         }
 	
 	gtk_grab_add (GTK_WIDGET (menu));
 }
@@ -1375,6 +1366,8 @@ static void
 edit_dentry (GtkWidget    *widget,
 	     ShowItemMenu *sim)
 {
+	GtkWidget *dialog;
+	PanelWidget *panel;
 	char *dir = NULL;
 
 	g_return_if_fail (sim != NULL);
@@ -1383,20 +1376,32 @@ edit_dentry (GtkWidget    *widget,
 	if (sim->mf)
 		dir = sim->mf->menudir;
 
-	panel_edit_dentry (sim->item_loc, dir,
-			   menuitem_to_screen (sim->menuitem));
+	panel = menu_get_panel (sim->menuitem);
+
+	dialog = panel_edit_dentry (sim->item_loc, dir,
+			   	    menuitem_to_screen (sim->menuitem));
+
+	panel_widget_register_open_dialog (panel, dialog);
 }
 
 static void
 edit_direntry (GtkWidget    *widget,
 	       ShowItemMenu *sim)
 {
+	GtkWidget *dialog;
+	PanelWidget *panel;
+
 	g_return_if_fail (sim != NULL);
 	g_return_if_fail (sim->mf != NULL);
 
-	panel_edit_direntry (sim->mf->menudir,
-			     sim->mf->dir_name,
-			     menuitem_to_screen (sim->menuitem));
+	panel = menu_get_panel (sim->menuitem);
+
+	dialog = panel_edit_direntry (sim->mf->menudir,
+			     	      sim->mf->dir_name,
+				      menuitem_to_screen (sim->menuitem));
+
+	panel_widget_register_open_dialog (panel, dialog);
+	
 }
 
 static void
@@ -1433,14 +1438,16 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 				return;
 			}
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this launcher to panel"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
-			g_signal_connect (menuitem, "activate",
-					  G_CALLBACK (add_app_to_panel),
-					  sim);
-			gtk_widget_set_sensitive (menuitem, objects_writable);
+			if ( ! panel_toplevel_get_locked_down (panel_widget->toplevel)) {
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("Add this launcher to panel"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
+				g_signal_connect (menuitem, "activate",
+						  G_CALLBACK (add_app_to_panel),
+						  sim);
+				gtk_widget_set_sensitive (menuitem, objects_writable);
+			}
 
 			menuitem = gtk_image_menu_item_new ();
 			setup_menuitem (menuitem, panel_menu_icon_get_size (),
@@ -1458,56 +1465,38 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 						   G_CALLBACK (gtk_menu_shell_deactivate),
 						   G_OBJECT (item->parent));
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Put into run dialog"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
-					       menuitem);
-			g_signal_connect (menuitem, "activate",
-					  G_CALLBACK (add_to_run_dialog),
-					  sim);
-			g_signal_connect_swapped
-				(G_OBJECT(menuitem),
-				 "activate",
-				 G_CALLBACK(gtk_menu_shell_deactivate),
-				 G_OBJECT(item->parent));
-
-			if (gnome_desktop_item_get_string (ii, "X-GNOME-DocPath") != NULL) {
-				char *title;
-				const char *name;
-
+			if ( ! panel_profile_get_inhibit_command_line ()) {
 				menuitem = gtk_image_menu_item_new ();
-				name = gnome_desktop_item_get_localestring (ii, GNOME_DESKTOP_ITEM_NAME);
-				title = g_strdup_printf (_("Help on %s"),
-							 (name != NULL) ? name : _("Application"));
 				setup_menuitem (menuitem, panel_menu_icon_get_size (),
-						NULL, title, FALSE);
-				g_free (title);
+						NULL, _("Put into run dialog"), FALSE);
 				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu),
-						 menuitem);
+						       menuitem);
 				g_signal_connect (menuitem, "activate",
-					          G_CALLBACK (show_help_on),
-					          sim);
-				g_signal_connect_swapped (G_OBJECT(menuitem),
-					 		  "activate",
-					 		   G_CALLBACK(gtk_menu_shell_deactivate),
-					 		   G_OBJECT(item->parent));
+						  G_CALLBACK (add_to_run_dialog),
+						  sim);
+				g_signal_connect_swapped
+					(G_OBJECT(menuitem),
+					 "activate",
+					 G_CALLBACK(gtk_menu_shell_deactivate),
+					 G_OBJECT(item->parent));
 			}
 
-			menuitem = gtk_image_menu_item_new ();
-			/*when activated we must pop down the first menu*/
-			g_signal_connect_swapped (G_OBJECT (menuitem),
-						   "activate",
-						   G_CALLBACK (gtk_menu_shell_deactivate),
-						   G_OBJECT (item->parent));
+			if ( ! panel_profile_get_inhibit_command_line ()) {
+				menuitem = gtk_image_menu_item_new ();
+				/*when activated we must pop down the first menu*/
+				g_signal_connect_swapped (G_OBJECT (menuitem),
+							  "activate",
+							  G_CALLBACK (gtk_menu_shell_deactivate),
+							  G_OBJECT (item->parent));
 
-			g_signal_connect (G_OBJECT(menuitem),
-					   "activate",
-					   G_CALLBACK(edit_dentry),
-					   sim);
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("_Properties"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
+				g_signal_connect (G_OBJECT(menuitem),
+						  "activate",
+						  G_CALLBACK(edit_dentry),
+						  sim);
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("_Properties"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (sim->menu), menuitem);
+			}
 
 			gnome_desktop_item_unref (ii);
 		}
@@ -1533,40 +1522,47 @@ show_item_menu (GtkWidget *item, GdkEventButton *bevent, ShowItemMenu *sim)
 							   submenu);
 			}
 
+			if ( ! panel_toplevel_get_locked_down (panel_widget->toplevel)) {
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL,
+						_("Add this as drawer to panel"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
+				g_signal_connect (G_OBJECT(menuitem), "activate",
+						  G_CALLBACK(add_menudrawer_to_panel),
+						  sim->mf);
+				gtk_widget_set_sensitive (menuitem,
+							  objects_writable &&
+							  toplevels_writable);
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL,
-					_("Add this as drawer to panel"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
-			g_signal_connect (G_OBJECT(menuitem), "activate",
-				   G_CALLBACK(add_menudrawer_to_panel),
-				   sim->mf);
-			gtk_widget_set_sensitive (menuitem, objects_writable && toplevels_writable);
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("Add this as menu to panel"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
+				g_signal_connect (G_OBJECT(menuitem), "activate",
+						  G_CALLBACK(add_menu_to_panel),
+						  sim->mf->menudir);
+				gtk_widget_set_sensitive (menuitem,
+							  objects_writable &&
+							  toplevels_writable);
+			}
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add this as menu to panel"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
-			g_signal_connect (G_OBJECT(menuitem), "activate",
-					   G_CALLBACK(add_menu_to_panel),
-					   sim->mf->menudir);
-			gtk_widget_set_sensitive (menuitem, objects_writable);
+			if ( ! panel_profile_get_inhibit_command_line ()) {
+				menuitem = gtk_image_menu_item_new ();
+				setup_menuitem (menuitem, panel_menu_icon_get_size (),
+						NULL, _("Add new item to this menu"), FALSE);
+				gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
+				/*when activated we must pop down the first menu*/
+				g_signal_connect_swapped (G_OBJECT (menuitem),
+							  "activate",
+							  G_CALLBACK (gtk_menu_shell_deactivate),
+							  G_OBJECT (item->parent));
 
-			menuitem = gtk_image_menu_item_new ();
-			setup_menuitem (menuitem, panel_menu_icon_get_size (),
-					NULL, _("Add new item to this menu"), FALSE);
-			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
-			/*when activated we must pop down the first menu*/
-			g_signal_connect_swapped (G_OBJECT (menuitem),
-						 "activate",
-						 G_CALLBACK (gtk_menu_shell_deactivate),
-						 G_OBJECT (item->parent));
-
-			g_signal_connect (menuitem, "activate",
-					  G_CALLBACK (add_new_app_to_menu),
-					  sim);
-			if ( ! panel_is_uri_writable (sim->mf->menudir))
-				gtk_widget_set_sensitive (menuitem, FALSE);
+				g_signal_connect (menuitem, "activate",
+						  G_CALLBACK (add_new_app_to_menu),
+						  sim);
+				if ( ! panel_is_uri_writable (sim->mf->menudir))
+					gtk_widget_set_sensitive (menuitem, FALSE);
+			}
 
 			menuitem = gtk_image_menu_item_new ();
 			/*when activated we must pop down the first menu*/
@@ -1615,7 +1611,7 @@ menuitem_button_press_event (GtkWidget      *menuitem,
 			     ShowItemMenu   *sim)
 {
 	/* no item menu in commie mode */
-	if (commie_mode)
+	if (panel_profile_get_locked_down ())
 		return FALSE;
 	
 	if (event->button == 3) {
@@ -1843,7 +1839,7 @@ setup_full_menuitem (GtkWidget   *menuitem,
 				  G_CALLBACK (destroy_item_menu),
 				  sim);
 
-		if ( ! commie_mode) {
+		if ( ! panel_profile_get_locked_down ()) {
 			gtk_drag_source_set(menuitem,
 					    GDK_BUTTON1_MASK|GDK_BUTTON2_MASK,
 					    menu_item_targets, 1,
@@ -1878,7 +1874,7 @@ setup_applet_drag (GtkWidget *menuitem, const char *iid)
 	};
 	
 	if (iid == NULL ||
-	    commie_mode)
+	    panel_profile_get_locked_down ())
 		return;
 	
 	gtk_drag_source_set (menuitem,
@@ -1904,7 +1900,7 @@ setup_internal_applet_drag (GtkWidget *menuitem, const char *applet_type)
 	};
 	
 	if (applet_type == NULL ||
-	    commie_mode)
+	    panel_profile_get_locked_down ())
 		return;
 	
 	gtk_drag_source_set (menuitem,
@@ -2199,10 +2195,11 @@ create_menuitem (GtkWidget *menu,
 
 	if (fr->type == FILE_REC_DIR) {
 		if (!gnome_folder)
-			gnome_folder = gnome_program_locate_file (NULL, 
-								  GNOME_FILE_DOMAIN_PIXMAP, 
-								  "gnome-folder.png", 
-								  TRUE, NULL);
+			gnome_folder = gnome_icon_theme_lookup_icon (
+						panel_icon_theme,
+                                               "gnome-fs-directory",
+                                               48, NULL, NULL);
+
 		if (!icon)
 			icon = gnome_folder;
 		else
@@ -2648,8 +2645,18 @@ append_internal_applets (GSList *list)
 {
 	static gboolean translated = FALSE;
 	int             i;
+	gboolean inhibit_command_line = panel_profile_get_inhibit_command_line ();
+	gboolean inhibit_force_quit = panel_profile_get_inhibit_force_quit ();
 
 	for (i = 0; i < G_N_ELEMENTS (action_buttons_info); i++) {
+		if (inhibit_command_line && 
+		    action_buttons_info [i].action_type == PANEL_ACTION_RUN)
+			continue;
+
+		if (inhibit_force_quit && 
+		    action_buttons_info [i].action_type == PANEL_ACTION_FORCE_QUIT)
+			continue;
+
 		if (!translated) {
 			action_buttons_info [i].name = _(action_buttons_info [i].name);
 			action_buttons_info [i].category = _(action_buttons_info [i].category);
@@ -2673,6 +2680,7 @@ create_applets_menu (GtkWidget             *menu,
 	GSList            *langs_gslist;
 	GSList            *applets = NULL;
 	GSList		  *item = NULL;
+	GSList            *disabled_applets;
 	gboolean           applets_writable;
 	gboolean           objects_writable;
 
@@ -2696,6 +2704,8 @@ create_applets_menu (GtkWidget             *menu,
 		langs_glist = langs_glist->next;
 	}
 
+	disabled_applets = panel_profile_get_disabled_applets ();
+
 	for (i = 0; i < applet_list->_length; i++) {
 		Bonobo_ServerInfo *info;
 		AppletMenuInfo    *applet;
@@ -2707,6 +2717,9 @@ create_applets_menu (GtkWidget             *menu,
 
 		info = &applet_list->_buffer [i];
 
+		if (g_slist_find_custom (disabled_applets, info->iid, (GCompareFunc)strcmp) != NULL)
+			continue;
+
 		name        = bonobo_server_info_prop_lookup (info, "name", langs_gslist);
 		category    = bonobo_server_info_prop_lookup (info, "panel:category", langs_gslist);
 	        description = bonobo_server_info_prop_lookup (info, "description", langs_gslist);
@@ -2724,7 +2737,7 @@ create_applets_menu (GtkWidget             *menu,
 		applet->untranslated_category = untranslated_category;
 		applet->description = description;
 		applet->icon = icon;
-		applet->drag_data = info->iid;;
+		applet->drag_data = info->iid;
 
 		applets = g_slist_append (applets, applet);
 	}
@@ -2773,6 +2786,8 @@ create_applets_menu (GtkWidget             *menu,
 	
 	g_slist_free (langs_gslist);
 	g_slist_free (applets);
+
+	panel_g_slist_deep_free	(disabled_applets);
 	
 	return menu;
 }
@@ -2913,7 +2928,8 @@ setup_remove_this_panel (GtkWidget *menu,
 
 	toplevels_writable = panel_profile_list_is_writable (PANEL_GCONF_TOPLEVELS);
 
-	if (panel_toplevel_is_last_unattached (panel_widget->toplevel))
+	if (panel_toplevel_is_last_unattached (panel_widget->toplevel) ||
+	    panel_toplevel_get_locked_down (panel_widget->toplevel))
 		gtk_widget_set_sensitive(menuitem, FALSE);
 	else
 		/* this can only be sensitive if we can actually write to
@@ -2955,61 +2971,62 @@ make_panel_submenu (PanelWidget *panel_widget,
 	Bonobo_ServerInfoList *applet_list;
 	GtkWidget             *menuitem, *submenu;
 
+	if ( ! panel_toplevel_get_locked_down (panel_widget->toplevel)) {
+		menuitem = gtk_image_menu_item_new ();
+		setup_menuitem (menuitem,
+				GTK_ICON_SIZE_MENU,
+				gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU),
+				_("_Add to Panel"),
+				FALSE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU),
-			_("_Add to Panel"),
-			FALSE);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		submenu = menu_new ();
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
+					   submenu);
 
-	submenu = menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
-				   submenu);
+		applet_list = instrument_add_submenu_for_reload (GTK_MENU_ITEM (menuitem), submenu);
 
-	applet_list = instrument_add_submenu_for_reload (GTK_MENU_ITEM (menuitem), submenu);
+		if ( ! panel_profile_list_is_writable (PANEL_GCONF_APPLETS) &&
+		     ! panel_profile_list_is_writable (PANEL_GCONF_OBJECTS)) {
+			/* if we can't write neither applets nor objects, just
+			   completely ignore this and make the whole submenu
+			   insensitive */
+			gtk_widget_set_sensitive (menuitem, FALSE);
+		} else {
+			make_add_submenu (submenu, applet_list);
+		}
 
-	if ( ! panel_profile_list_is_writable (PANEL_GCONF_APPLETS) &&
-	     ! panel_profile_list_is_writable (PANEL_GCONF_OBJECTS)) {
-		/* if we can't write neither applets nor objects, just
-		   completely ignore this and make the whole submenu
-		   insensitive */
-		gtk_widget_set_sensitive (menuitem, FALSE);
-	} else {
-		make_add_submenu (submenu, applet_list);
+		menuitem = gtk_image_menu_item_new ();
+
+		setup_menuitem (menuitem, 
+				GTK_ICON_SIZE_MENU,
+				gtk_image_new_from_stock (GTK_STOCK_DELETE, GTK_ICON_SIZE_MENU),
+				_("_Delete This Panel"),
+				FALSE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (G_OBJECT (menuitem), "activate",
+				  G_CALLBACK (remove_panel),
+				  NULL);
+		g_signal_connect (G_OBJECT (menu), "show",
+				  G_CALLBACK(setup_remove_this_panel),
+				  menuitem);
+
+		menuitem = gtk_image_menu_item_new ();
+		setup_menuitem (menuitem,
+				GTK_ICON_SIZE_MENU,
+				gtk_image_new_from_stock (
+							  GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU),
+				_("_Properties"),
+				FALSE);
+
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect_swapped (menuitem, "activate",
+					  G_CALLBACK (panel_properties_dialog_present), 
+					  panel_widget->toplevel);
+
+		add_menu_separator (menu);
 	}
 
-	menuitem = gtk_image_menu_item_new ();
-
-	setup_menuitem (menuitem, 
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU),
-			_("_Delete This Panel"),
-			FALSE);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect (G_OBJECT (menuitem), "activate",
-			    G_CALLBACK (remove_panel),
-			    NULL);
-	g_signal_connect (G_OBJECT (menu), "show",
-			    G_CALLBACK(setup_remove_this_panel),
-			    menuitem);
-
-	menuitem = gtk_image_menu_item_new ();
-	setup_menuitem (menuitem,
-			GTK_ICON_SIZE_MENU,
-			gtk_image_new_from_stock (
-				GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU),
-			_("_Properties"),
-			FALSE);
-
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect_swapped (menuitem, "activate",
-				  G_CALLBACK (panel_properties_dialog_present), 
-				  panel_widget->toplevel);
-
-	add_menu_separator (menu);
-
 	menuitem = gtk_image_menu_item_new ();
 	setup_menuitem (menuitem, 
 			GTK_ICON_SIZE_MENU,
@@ -3020,8 +3037,6 @@ make_panel_submenu (PanelWidget *panel_widget,
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (create_new_panel), 
 			  NULL);
-	/* this can only be sensitive if we can actually write to the
-	   toplevels list */
 	gtk_widget_set_sensitive (menuitem, 
 				  panel_profile_list_is_writable (PANEL_GCONF_TOPLEVELS));
 
@@ -3044,7 +3059,7 @@ create_panel_context_menu (PanelWidget *panel)
 
 	retval = menu_new ();
 
-	if (!commie_mode)
+	if ( ! panel_profile_get_locked_down ())
 		make_panel_submenu (panel, retval);
 
 	menuitem = gtk_image_menu_item_new ();
@@ -3097,6 +3112,9 @@ ask_about_launcher_cb (GtkWidget *widget)
 	PanelData   *pd;
 	int          insertion_pos;
 
+	if (panel_profile_get_inhibit_command_line ())
+		return;
+
 	panel_widget = menu_get_panel (widget);
 
 	pd = g_object_get_data (G_OBJECT (panel_widget->toplevel), "PanelData");
@@ -3119,14 +3137,16 @@ make_add_submenu (GtkWidget             *menu,
 
 	create_applets_menu (menu, applet_list);
 
-	menuitem = gtk_image_menu_item_new ();
-	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."), TRUE);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	g_signal_connect (G_OBJECT(menuitem), "activate",
-			   G_CALLBACK(ask_about_launcher_cb),NULL);
-	setup_internal_applet_drag(menuitem, "LAUNCHER:ASK");
-	gtk_widget_set_sensitive (menuitem, objects_writable);
+	if ( ! panel_profile_get_inhibit_command_line ()) {
+		menuitem = gtk_image_menu_item_new ();
+		setup_stock_menu_item (
+				       menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."), TRUE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+		g_signal_connect (G_OBJECT(menuitem), "activate",
+				  G_CALLBACK(ask_about_launcher_cb),NULL);
+		setup_internal_applet_drag(menuitem, "LAUNCHER:ASK");
+		gtk_widget_set_sensitive (menuitem, objects_writable);
+	}
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
@@ -3319,7 +3339,7 @@ create_root_menu (GtkWidget   *root_menu,
 					  FALSE /*launcher_add */);
 	}
 
-	if ( ! no_run_box && extra_items) {
+	if ( ! panel_profile_get_inhibit_command_line () && extra_items) {
 		add_menu_separator (root_menu);
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
