@@ -27,10 +27,8 @@
 #include <libgnomeui/libgnomeui.h>
 #include <libgnome/libgnome.h>
 
-#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "panel-util.h"
 
@@ -45,8 +43,6 @@
 #include "panel-globals.h"
 #include "launcher.h"
 
-static gboolean panel_is_url (const char *url);
-
 int
 panel_ditem_launch (const GnomeDesktopItem       *item,
 		    GList                        *file_list,
@@ -70,133 +66,17 @@ panel_show_help (GdkScreen  *screen,
 	GError *error = NULL;
 
 	if (!egg_help_display_desktop_on_screen (NULL, "user-guide", doc_name, linkid, screen, &error)) {
-		char *msg;
-		msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
-			_("Cannot display help document"),
-			_("Details"), error != NULL ? error->message : "");
-
 		panel_error_dialog (
 			screen,
 			"cannot_show_help",
-			msg);
+			_("Cannot display help document"),
+			"%s",
+			error != NULL ? error->message : "");
 
-		g_free (msg);
 		g_clear_error (&error);
 	}
 }
 
-static gboolean
-panel_show_gnome_help (GdkScreen   *screen,
-		       const char  *docpath,
-		       GError     **error)
-{
-	char *app, *p, *path;
-	gboolean retval;
-
-	app = g_strdup (docpath);
-
-	p = strchr (app, '/');
-
-	if (p == NULL) {
-		g_free (app);
-		g_set_error (error,
-			     PANEL_HELP_ERROR,
-			     PANEL_HELP_ERROR_NOT_FOUND,
-			     /* XXX: Not really a correct error,
-			      * but just somewhat correct */
-			     _("Help document not found"));
-		return FALSE;
-	}
-
-	path = p+1;
-	*p = '\0';
-
-	retval = TRUE;
-
-	if ( ! egg_help_display_desktop_on_screen (NULL, app, path, NULL, screen, error)) {
-		retval = egg_help_display_with_doc_id_on_screen (
-				NULL, app, path, NULL, screen, error);
-	}
-
-	g_free (app);
-
-	return retval;
-}
-
-static gboolean
-panel_show_kde_help (GdkScreen   *screen,
-		     const char  *docpath,
-		     GError     **error)
-{
-	const GList *li;
-
-	if ( ! g_file_test (KDE_DOCDIR, G_FILE_TEST_EXISTS)) {
-		g_set_error (error,
-			     PANEL_HELP_ERROR,
-			     PANEL_HELP_ERROR_NOT_FOUND,
-			     _("Help document not found"));
-		return FALSE;
-	}
-
-	for (li = gnome_i18n_get_language_list ("LC_MESSAGES");
-	     li != NULL;
-	     li = li->next) {
-		char *fullpath = g_strdup_printf ("%s/HTML/%s/%s",
-						  KDE_DOCDIR,
-						  (char *)li->data,
-						  docpath);
-		if (g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
-			gboolean retval;
-			char *uri = g_strconcat ("ghelp:", fullpath, NULL);
-			g_free (fullpath);
-			retval = egg_help_display_uri_on_screen (uri, screen, error);
-			g_free (uri);
-			return retval;
-		}
-		g_free (fullpath);
-	}
-
-	g_set_error (error,
-		     PANEL_HELP_ERROR,
-		     PANEL_HELP_ERROR_NOT_FOUND,
-		     _("Help document not found"));
-
-	return FALSE;
-}
-
-gboolean
-panel_show_gnome_kde_help (GdkScreen   *screen,
-			   const char  *docpath,
-			   GError     **error)
-{
-	if (string_empty (docpath)) {
-		g_set_error (error,
-			     PANEL_HELP_ERROR,
-			     PANEL_HELP_ERROR_NO_DOCPATH,
-			     _("No document to show"));
-		return FALSE;
-	}
-
-	if (panel_is_url (docpath))
-		return egg_help_display_uri_on_screen (docpath, screen, error);
-
-	if ( ! panel_show_gnome_help (screen, docpath, error)) {
-		return panel_show_kde_help (screen, docpath, error);
-	}
-
-	return TRUE;
-}
-
-GQuark
-panel_help_error_quark (void)
-{
-	static GQuark q = 0;
-	if (q == 0)
-		q = g_quark_from_static_string ("panel-help-error-quark");
-
-	return q;
-}
-
 static void
 updated (GtkWidget *w, gpointer data)
 {
@@ -432,7 +312,9 @@ panel_dialog (GdkScreen  *screen,
 	GtkWidget *dialog;
 
 	dialog = gtk_message_dialog_new (
-			NULL, 0, type, GTK_BUTTONS_OK, "foo");
+			NULL, 0, type, GTK_BUTTONS_OK,
+			/* No need to translate this, this should NEVER happen */
+			"Error with displaying error for dialog of class %s", class);
 	gtk_widget_add_events (dialog, GDK_KEY_PRESS_MASK);
 	g_signal_connect (dialog, "event",
 			  G_CALLBACK (panel_dialog_window_event), NULL);
@@ -441,6 +323,7 @@ panel_dialog (GdkScreen  *screen,
 
 	gtk_window_set_wmclass (GTK_WINDOW (dialog), class, "Panel");
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	gtk_widget_show_all (dialog);
 
@@ -456,20 +339,36 @@ panel_dialog (GdkScreen  *screen,
 GtkWidget *
 panel_error_dialog (GdkScreen  *screen,
 		    const char *class,
-		    const char *format,
+		    const char *primary_format,
+		    const char *secondary_format,
 		    ...)
 {
 	GtkWidget *w;
-	char *s;
+	char *sec = NULL, *format, *s;
 	va_list ap;
 
-	if (format == NULL) {
-		g_warning ("NULL error dialog");
+	if (primary_format == NULL) {
+		g_warning ("NULL dialog");
 		s = g_strdup ("(null)");
 	} else {
-		va_start (ap, format);
+		if (secondary_format == NULL)
+			format = (char *)primary_format;
+		else {
+			sec = g_strdup_printf (_("Details: %s"), secondary_format);
+
+			format = g_strdup_printf ("<b>%s</b>\n\n%s",
+						  primary_format,
+						  sec);
+
+			g_free (sec);
+		}
+
+		va_start (ap, secondary_format);
 		s = g_strdup_vprintf (format, ap);
 		va_end (ap);
+
+		if (format != primary_format)
+			g_free (format);
 	}
 
 	w = panel_dialog (screen, GTK_MESSAGE_ERROR, class, s);
@@ -495,24 +394,6 @@ panel_find_applet_index (GtkWidget *widget)
 	return i;
 }
 
-/* is url showable by gnome_url_show */
-static gboolean
-panel_is_url (const char *url)
-{
-	if (strncmp (url, "http://", strlen ("http://")) == 0 ||
-	    strncmp (url, "https://", strlen ("https://")) == 0 ||
-	    strncmp (url, "gopher://", strlen ("gopher://")) == 0 ||
-	    strncmp (url, "ftp://", strlen ("ftp://")) == 0 ||
-	    strncmp (url, "file:", strlen ("file:")) == 0 ||
-	    strncmp (url, "ghelp:", strlen ("ghelp:")) == 0 ||
-	    strncmp (url, "help:", strlen ("help:")) == 0 ||
-	    strncmp (url, "man:", strlen ("man:")) == 0 ||
-	    strncmp (url, "info:", strlen ("info:")) == 0)
-		return TRUE;
-	else
-		return FALSE;
-}
-
 void
 panel_push_window_busy (GtkWidget *window)
 {
@@ -927,18 +808,13 @@ panel_lock_screen (GdkScreen *screen)
 	if (!screen)
 		screen = gdk_screen_get_default ();
 
-	if (egg_screen_execute_async (screen, g_get_home_dir (), 2, argv) < 0) {
-		char *msg;
-		msg = g_strdup_printf ("<b>%s</b>\n\n%s",
-			_("Cannot execute xscreensaver"),
-			_("Details: xscreensaver-command not found"));
-
+	if (egg_screen_execute_async (screen, g_get_home_dir (), 2, argv) < 0)
 		panel_error_dialog (screen,
 			"cannot_exec_xscreensaver",
-			msg);
-
-		g_free (msg);
-	}
+			 _("Cannot execute %s"),
+			 _("%s - command not found"),
+			 "xscreensaver",
+			 "xscreensaver");
 }
 
 
@@ -994,8 +870,8 @@ panel_make_unique_path (const char *dir,
 		int   rnd;
 		int   word;
 
-		rnd = rand ();
-		word = rand () % NUM_OF_WORDS;
+		rnd = g_random_int ();
+		word = g_random_int () % NUM_OF_WORDS;
 
 		filename = g_strdup_printf ("%s-%010x%s",
 					    words [word],
